<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Hooks Documentation

- **[erk.md](erk.md)** — working with erk-specific hooks, understanding context-aware reminders, modifying project hooks, creating project-scoped hooks, testing hooks with @project_scoped decorator, using @project_scoped decorator, creating hooks that only fire in managed projects
- **[hooks.md](hooks.md)** — creating hooks, modifying hooks, understanding hook lifecycle
